/*
** file.c -- file handling routines for ShowTime
**
** Copyright (C) 1994 by Michael J. Gourlay
**
** NO WARRANTEES, EXPRESS OR IMPLIED.
*/

#include <fcntl.h>
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include "showtime.h"
#include "video.h"
#include "image.h"
#include "pbm.h"
#include "cmap.h"
#include "pic.h"

#include "file.h"

/* ====================================================================== */

/* get_le_word : get from fio a 2-byte little-endian unsigned integer
*/
long
get_le_word(FILE * fio)
{
  unsigned char b1, b2;

  /* least significant byte comes first */
  GET_BYTE(fio, b1);

  /* most significant byte comes last */
  GET_BYTE(fio, b2);

  return(b1 + b2*256);
}

/* ---------------------------------------------------------------------- */

/* get_block : get from fio an block of n bytes, and store it in buf
** return EOF if there is a read error, or 0 otherwise
*/
short
get_block(FILE * fio, unsigned char *buf, long n)
{
  int rv;

  if(feof(fio)) return(EOF);
  rv=fread(buf, 1, (size_t)n, fio);
  if(rv!=n) {
    if(rv) {
      logmesg("get_block: EOF/read error reading byte %i/%i\n", rv, n);
    }
    return(EOF);
  }

  return(0);
}

/* ---------------------------------------------------------------------- */

/* open_file : open a file and return its file pointer
*/
FILE *
open_file(char *filename)
{
  FILE *  fio;

  /* Open a file */
  if((fio = fopen(filename, "rb"))==NULL)
  {
    logmesg("\nopen_file: Unable to open file \"%s\".\n", filename);
  }

  return(fio);
}
